Index: lib/src/runner/loader.dart |
diff --git a/lib/src/runner/loader.dart b/lib/src/runner/loader.dart |
index 33092e1925f5bfc78cb9f54c38ad0e52cf55fdc9..b7594db40536b4bc904c9b47078422a91d145e44 100644 |
--- a/lib/src/runner/loader.dart |
+++ b/lib/src/runner/loader.dart |
@@ -62,8 +62,8 @@ class Loader { |
/// Loads all test suites in [dir]. |
/// |
/// This will load tests from files that end in "_test.dart". Any tests that |
/// fail to load will be emitted as [LoadException]s. |
/// |
/// This emits [LoadSuite]s that must then be run to emit the actual |
/// [RunnerSuite]s defined in the file. |
@@ -72,7 +72,7 @@ class Loader { |
.map((entry) { |
if (entry is! File) return new Stream.fromIterable([]); |
- if (!entry.path.endsWith("_test.dart")) { |
+ if (!_config.filename.matches(p.basename(entry.path))) { |
return new Stream.fromIterable([]); |
} |
@@ -62,8 +62,8 @@ class Loader { |
/// Loads all test suites in [dir]. |
/// |
- /// This will load tests from files that end in "_test.dart". Any tests that |
- /// fail to load will be emitted as [LoadException]s. |
+ /// This will load tests from files that match the configuration's filename |
+ /// glob. Any tests that fail to load will be emitted as [LoadException]s. |
/// |
/// This emits [LoadSuite]s that must then be run to emit the actual |